| phines_metadata | R Documentation |
Internal list containing hex codes and scientific stages (BBCH, MSI, and ST-Mod).
phines_metadata
An object of class list of length 5.
A nested list where each element represents a palette containing
vectors of colors, biological stages, and scientific codes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.