show_phines: Visual Preview of Palettes

View source: R/palettes.R

show_phinesR Documentation

Visual Preview of Palettes

Description

Visual Preview of Palettes

Usage

show_phines(name)

Arguments

name

Palette name.

Value

No return value, called for side effects. This function generates a plot in the active graphics device showing the color blocks of the palette.

Examples

# Use oldpar to respect user's graphical settings
oldpar <- par(no.readonly = TRUE)
show_phines("coral_bleach")
par(oldpar)

palettephines documentation built on April 25, 2026, 1:07 a.m.