| show_phines | R Documentation |
Visual Preview of Palettes
show_phines(name)
name |
Palette name. |
No return value, called for side effects. This function generates a plot in the active graphics device showing the color blocks of the palette.
# Use oldpar to respect user's graphical settings
oldpar <- par(no.readonly = TRUE)
show_phines("coral_bleach")
par(oldpar)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.